@@ -41,10 +41,20 @@ constant(const char *name)
             if (strEQ(name, "GLOBAL_WIN32")) return CURL_GLOBAL_WIN32;
             break;
         case 'H':
+            if (strEQ(name, "HTTPPOST_BUFFER")) return CURL_HTTPPOST_BUFFER;
+            if (strEQ(name, "HTTPPOST_CALLBACK")) return CURL_HTTPPOST_CALLBACK;
+            if (strEQ(name, "HTTPPOST_FILENAME")) return CURL_HTTPPOST_FILENAME;
+            if (strEQ(name, "HTTPPOST_LARGE")) return CURL_HTTPPOST_LARGE;
+            if (strEQ(name, "HTTPPOST_PTRBUFFER")) return CURL_HTTPPOST_PTRBUFFER;
+            if (strEQ(name, "HTTPPOST_PTRCONTENTS")) return CURL_HTTPPOST_PTRCONTENTS;
+            if (strEQ(name, "HTTPPOST_PTRNAME")) return CURL_HTTPPOST_PTRNAME;
+            if (strEQ(name, "HTTPPOST_READFILE")) return CURL_HTTPPOST_READFILE;
             if (strEQ(name, "HTTP_VERSION_1_0")) return CURL_HTTP_VERSION_1_0;
             if (strEQ(name, "HTTP_VERSION_1_1")) return CURL_HTTP_VERSION_1_1;
             if (strEQ(name, "HTTP_VERSION_2")) return CURL_HTTP_VERSION_2;
+            if (strEQ(name, "HTTP_VERSION_2TLS")) return CURL_HTTP_VERSION_2TLS;
             if (strEQ(name, "HTTP_VERSION_2_0")) return CURL_HTTP_VERSION_2_0;
+            if (strEQ(name, "HTTP_VERSION_2_PRIOR_KNOWLEDGE")) return CURL_HTTP_VERSION_2_PRIOR_KNOWLEDGE;
             if (strEQ(name, "HTTP_VERSION_NONE")) return CURL_HTTP_VERSION_NONE;
             break;
         case 'I':
@@ -67,6 +77,7 @@ constant(const char *name)
             break;
         case 'M':
             if (strEQ(name, "MAX_HTTP_HEADER")) return CURL_MAX_HTTP_HEADER;
+            if (strEQ(name, "MAX_READ_SIZE")) return CURL_MAX_READ_SIZE;
             if (strEQ(name, "MAX_WRITE_SIZE")) return CURL_MAX_WRITE_SIZE;
             break;
         case 'N':
@@ -107,12 +118,19 @@ constant(const char *name)
             if (strEQ(name, "SOCKOPT_ERROR")) return CURL_SOCKOPT_ERROR;
             if (strEQ(name, "SOCKOPT_OK")) return CURL_SOCKOPT_OK;
             if (strEQ(name, "SSLVERSION_DEFAULT")) return CURL_SSLVERSION_DEFAULT;
+            if (strEQ(name, "SSLVERSION_MAX_DEFAULT")) return CURL_SSLVERSION_MAX_DEFAULT;
+            if (strEQ(name, "SSLVERSION_MAX_NONE")) return CURL_SSLVERSION_MAX_NONE;
+            if (strEQ(name, "SSLVERSION_MAX_TLSv1_0")) return CURL_SSLVERSION_MAX_TLSv1_0;
+            if (strEQ(name, "SSLVERSION_MAX_TLSv1_1")) return CURL_SSLVERSION_MAX_TLSv1_1;
+            if (strEQ(name, "SSLVERSION_MAX_TLSv1_2")) return CURL_SSLVERSION_MAX_TLSv1_2;
+            if (strEQ(name, "SSLVERSION_MAX_TLSv1_3")) return CURL_SSLVERSION_MAX_TLSv1_3;
             if (strEQ(name, "SSLVERSION_SSLv2")) return CURL_SSLVERSION_SSLv2;
             if (strEQ(name, "SSLVERSION_SSLv3")) return CURL_SSLVERSION_SSLv3;
             if (strEQ(name, "SSLVERSION_TLSv1")) return CURL_SSLVERSION_TLSv1;
             if (strEQ(name, "SSLVERSION_TLSv1_0")) return CURL_SSLVERSION_TLSv1_0;
             if (strEQ(name, "SSLVERSION_TLSv1_1")) return CURL_SSLVERSION_TLSv1_1;
             if (strEQ(name, "SSLVERSION_TLSv1_2")) return CURL_SSLVERSION_TLSv1_2;
+            if (strEQ(name, "SSLVERSION_TLSv1_3")) return CURL_SSLVERSION_TLSv1_3;
             break;
         case 'T':
             if (strEQ(name, "TIMECOND_IFMODSINCE")) return CURL_TIMECOND_IFMODSINCE;
@@ -131,6 +149,7 @@ constant(const char *name)
             if (strEQ(name, "VERSION_GSSAPI")) return CURL_VERSION_GSSAPI;
             if (strEQ(name, "VERSION_GSSNEGOTIATE")) return CURL_VERSION_GSSNEGOTIATE;
             if (strEQ(name, "VERSION_HTTP2")) return CURL_VERSION_HTTP2;
+            if (strEQ(name, "VERSION_HTTPS_PROXY")) return CURL_VERSION_HTTPS_PROXY;
             if (strEQ(name, "VERSION_IDN")) return CURL_VERSION_IDN;
             if (strEQ(name, "VERSION_IPV6")) return CURL_VERSION_IPV6;
             if (strEQ(name, "VERSION_KERBEROS4")) return CURL_VERSION_KERBEROS4;
@@ -139,6 +158,7 @@ constant(const char *name)
             if (strEQ(name, "VERSION_LIBZ")) return CURL_VERSION_LIBZ;
             if (strEQ(name, "VERSION_NTLM")) return CURL_VERSION_NTLM;
             if (strEQ(name, "VERSION_NTLM_WB")) return CURL_VERSION_NTLM_WB;
+            if (strEQ(name, "VERSION_PSL")) return CURL_VERSION_PSL;
             if (strEQ(name, "VERSION_SPNEGO")) return CURL_VERSION_SPNEGO;
             if (strEQ(name, "VERSION_SSL")) return CURL_VERSION_SSL;
             if (strEQ(name, "VERSION_SSPI")) return CURL_VERSION_SSPI;
@@ -257,6 +277,8 @@ constant(const char *name)
         case 'L':
         case 'M':
         case 'N':
+            if (strEQ(name, "NO_REVOKE")) return CURLSSLOPT_NO_REVOKE;
+            break;
         case 'O':
         case 'P':
         case 'Q':
@@ -280,6 +302,8 @@ constant(const char *name)
             if (strEQ(name, "AXTLS")) return CURLSSLBACKEND_AXTLS;
             break;
         case 'B':
+            if (strEQ(name, "BORINGSSL")) return CURLSSLBACKEND_BORINGSSL;
+            break;
         case 'C':
             if (strEQ(name, "CYASSL")) return CURLSSLBACKEND_CYASSL;
             break;
@@ -297,7 +321,11 @@ constant(const char *name)
         case 'J':
         case 'K':
         case 'L':
+            if (strEQ(name, "LIBRESSL")) return CURLSSLBACKEND_LIBRESSL;
+            break;
         case 'M':
+            if (strEQ(name, "MBEDTLS")) return CURLSSLBACKEND_MBEDTLS;
+            break;
         case 'N':
             if (strEQ(name, "NONE")) return CURLSSLBACKEND_NONE;
             if (strEQ(name, "NSS")) return CURLSSLBACKEND_NSS;
@@ -317,6 +345,8 @@ constant(const char *name)
         case 'U':
         case 'V':
         case 'W':
+            if (strEQ(name, "WOLFSSL")) return CURLSSLBACKEND_WOLFSSL;
+            break;
         case 'X':
         case 'Y':
         case 'Z':
@@ -501,6 +531,7 @@ constant(const char *name)
         case 'G':
         case 'H':
             if (strEQ(name, "HTTP")) return CURLPROXY_HTTP;
+            if (strEQ(name, "HTTPS")) return CURLPROXY_HTTPS;
             if (strEQ(name, "HTTP_1_0")) return CURLPROXY_HTTP_1_0;
             break;
         case 'I':
@@ -650,6 +681,7 @@ constant(const char *name)
         name += 8;
         switch (*name) {
         case 'A':
+            if (strEQ(name, "ABSTRACT_UNIX_SOCKET")) return CURLOPT_ABSTRACT_UNIX_SOCKET;
             if (strEQ(name, "ACCEPTTIMEOUT_MS")) return CURLOPT_ACCEPTTIMEOUT_MS;
             if (strEQ(name, "ACCEPT_ENCODING")) return CURLOPT_ACCEPT_ENCODING;
             if (strEQ(name, "ADDRESS_SCOPE")) return CURLOPT_ADDRESS_SCOPE;
@@ -672,6 +704,7 @@ constant(const char *name)
             if (strEQ(name, "CONNECTTIMEOUT")) return CURLOPT_CONNECTTIMEOUT;
             if (strEQ(name, "CONNECTTIMEOUT_MS")) return CURLOPT_CONNECTTIMEOUT_MS;
             if (strEQ(name, "CONNECT_ONLY")) return CURLOPT_CONNECT_ONLY;
+            if (strEQ(name, "CONNECT_TO")) return CURLOPT_CONNECT_TO;
             if (strEQ(name, "CONV_FROM_NETWORK_FUNCTION")) return CURLOPT_CONV_FROM_NETWORK_FUNCTION;
             if (strEQ(name, "CONV_FROM_UTF8_FUNCTION")) return CURLOPT_CONV_FROM_UTF8_FUNCTION;
             if (strEQ(name, "CONV_TO_NETWORK_FUNCTION")) return CURLOPT_CONV_TO_NETWORK_FUNCTION;
@@ -688,6 +721,7 @@ constant(const char *name)
         case 'D':
             if (strEQ(name, "DEBUGDATA")) return CURLOPT_DEBUGDATA;
             if (strEQ(name, "DEBUGFUNCTION")) return CURLOPT_DEBUGFUNCTION;
+            if (strEQ(name, "DEFAULT_PROTOCOL")) return CURLOPT_DEFAULT_PROTOCOL;
             if (strEQ(name, "DIRLISTONLY")) return CURLOPT_DIRLISTONLY;
             if (strEQ(name, "DNS_CACHE_TIMEOUT")) return CURLOPT_DNS_CACHE_TIMEOUT;
             if (strEQ(name, "DNS_INTERFACE")) return CURLOPT_DNS_INTERFACE;
@@ -760,6 +794,7 @@ constant(const char *name)
             break;
         case 'J':
         case 'K':
+            if (strEQ(name, "KEEP_SENDING_ON_ERROR")) return CURLOPT_KEEP_SENDING_ON_ERROR;
             if (strEQ(name, "KEYPASSWD")) return CURLOPT_KEYPASSWD;
             if (strEQ(name, "KRB4LEVEL")) return CURLOPT_KRB4LEVEL;
             if (strEQ(name, "KRBLEVEL")) return CURLOPT_KRBLEVEL;
@@ -810,6 +845,7 @@ constant(const char *name)
             if (strEQ(name, "POSTQUOTE")) return CURLOPT_POSTQUOTE;
             if (strEQ(name, "POSTREDIR")) return CURLOPT_POSTREDIR;
             if (strEQ(name, "PREQUOTE")) return CURLOPT_PREQUOTE;
+            if (strEQ(name, "PRE_PROXY")) return CURLOPT_PRE_PROXY;
             if (strEQ(name, "PRIVATE")) return CURLOPT_PRIVATE;
             if (strEQ(name, "PROGRESSDATA")) return CURLOPT_PROGRESSDATA;
             if (strEQ(name, "PROGRESSFUNCTION")) return CURLOPT_PROGRESSFUNCTION;
@@ -822,7 +858,24 @@ constant(const char *name)
             if (strEQ(name, "PROXYTYPE")) return CURLOPT_PROXYTYPE;
             if (strEQ(name, "PROXYUSERNAME")) return CURLOPT_PROXYUSERNAME;
             if (strEQ(name, "PROXYUSERPWD")) return CURLOPT_PROXYUSERPWD;
+            if (strEQ(name, "PROXY_CAINFO")) return CURLOPT_PROXY_CAINFO;
+            if (strEQ(name, "PROXY_CAPATH")) return CURLOPT_PROXY_CAPATH;
+            if (strEQ(name, "PROXY_CRLFILE")) return CURLOPT_PROXY_CRLFILE;
+            if (strEQ(name, "PROXY_KEYPASSWD")) return CURLOPT_PROXY_KEYPASSWD;
+            if (strEQ(name, "PROXY_PINNEDPUBLICKEY")) return CURLOPT_PROXY_PINNEDPUBLICKEY;
             if (strEQ(name, "PROXY_SERVICE_NAME")) return CURLOPT_PROXY_SERVICE_NAME;
+            if (strEQ(name, "PROXY_SSLCERT")) return CURLOPT_PROXY_SSLCERT;
+            if (strEQ(name, "PROXY_SSLCERTTYPE")) return CURLOPT_PROXY_SSLCERTTYPE;
+            if (strEQ(name, "PROXY_SSLKEY")) return CURLOPT_PROXY_SSLKEY;
+            if (strEQ(name, "PROXY_SSLKEYTYPE")) return CURLOPT_PROXY_SSLKEYTYPE;
+            if (strEQ(name, "PROXY_SSLVERSION")) return CURLOPT_PROXY_SSLVERSION;
+            if (strEQ(name, "PROXY_SSL_CIPHER_LIST")) return CURLOPT_PROXY_SSL_CIPHER_LIST;
+            if (strEQ(name, "PROXY_SSL_OPTIONS")) return CURLOPT_PROXY_SSL_OPTIONS;
+            if (strEQ(name, "PROXY_SSL_VERIFYHOST")) return CURLOPT_PROXY_SSL_VERIFYHOST;
+            if (strEQ(name, "PROXY_SSL_VERIFYPEER")) return CURLOPT_PROXY_SSL_VERIFYPEER;
+            if (strEQ(name, "PROXY_TLSAUTH_PASSWORD")) return CURLOPT_PROXY_TLSAUTH_PASSWORD;
+            if (strEQ(name, "PROXY_TLSAUTH_TYPE")) return CURLOPT_PROXY_TLSAUTH_TYPE;
+            if (strEQ(name, "PROXY_TLSAUTH_USERNAME")) return CURLOPT_PROXY_TLSAUTH_USERNAME;
             if (strEQ(name, "PROXY_TRANSFER_MODE")) return CURLOPT_PROXY_TRANSFER_MODE;
             if (strEQ(name, "PUT")) return CURLOPT_PUT;
             break;
@@ -836,6 +889,7 @@ constant(const char *name)
             if (strEQ(name, "READFUNCTION")) return CURLOPT_READFUNCTION;
             if (strEQ(name, "REDIR_PROTOCOLS")) return CURLOPT_REDIR_PROTOCOLS;
             if (strEQ(name, "REFERER")) return CURLOPT_REFERER;
+            if (strEQ(name, "REQUEST_TARGET")) return CURLOPT_REQUEST_TARGET;
             if (strEQ(name, "RESOLVE")) return CURLOPT_RESOLVE;
             if (strEQ(name, "RESUME_FROM")) return CURLOPT_RESUME_FROM;
             if (strEQ(name, "RESUME_FROM_LARGE")) return CURLOPT_RESUME_FROM_LARGE;
@@ -856,6 +910,7 @@ constant(const char *name)
             if (strEQ(name, "SHARE")) return CURLOPT_SHARE;
             if (strEQ(name, "SOCKOPTDATA")) return CURLOPT_SOCKOPTDATA;
             if (strEQ(name, "SOCKOPTFUNCTION")) return CURLOPT_SOCKOPTFUNCTION;
+            if (strEQ(name, "SOCKS5_AUTH")) return CURLOPT_SOCKS5_AUTH;
             if (strEQ(name, "SOCKS5_GSSAPI_NEC")) return CURLOPT_SOCKS5_GSSAPI_NEC;
             if (strEQ(name, "SOCKS5_GSSAPI_SERVICE")) return CURLOPT_SOCKS5_GSSAPI_SERVICE;
             if (strEQ(name, "SSH_AUTH_TYPES")) return CURLOPT_SSH_AUTH_TYPES;
@@ -886,14 +941,20 @@ constant(const char *name)
             if (strEQ(name, "SSL_VERIFYPEER")) return CURLOPT_SSL_VERIFYPEER;
             if (strEQ(name, "SSL_VERIFYSTATUS")) return CURLOPT_SSL_VERIFYSTATUS;
             if (strEQ(name, "STDERR")) return CURLOPT_STDERR;
+            if (strEQ(name, "STREAM_DEPENDS")) return CURLOPT_STREAM_DEPENDS;
+            if (strEQ(name, "STREAM_DEPENDS_E")) return CURLOPT_STREAM_DEPENDS_E;
+            if (strEQ(name, "STREAM_WEIGHT")) return CURLOPT_STREAM_WEIGHT;
+            if (strEQ(name, "SUPPRESS_CONNECT_HEADERS")) return CURLOPT_SUPPRESS_CONNECT_HEADERS;
             break;
         case 'T':
+            if (strEQ(name, "TCP_FASTOPEN")) return CURLOPT_TCP_FASTOPEN;
             if (strEQ(name, "TCP_KEEPALIVE")) return CURLOPT_TCP_KEEPALIVE;
             if (strEQ(name, "TCP_KEEPIDLE")) return CURLOPT_TCP_KEEPIDLE;
             if (strEQ(name, "TCP_KEEPINTVL")) return CURLOPT_TCP_KEEPINTVL;
             if (strEQ(name, "TCP_NODELAY")) return CURLOPT_TCP_NODELAY;
             if (strEQ(name, "TELNETOPTIONS")) return CURLOPT_TELNETOPTIONS;
             if (strEQ(name, "TFTP_BLKSIZE")) return CURLOPT_TFTP_BLKSIZE;
+            if (strEQ(name, "TFTP_NO_OPTIONS")) return CURLOPT_TFTP_NO_OPTIONS;
             if (strEQ(name, "TIMECONDITION")) return CURLOPT_TIMECONDITION;
             if (strEQ(name, "TIMEOUT")) return CURLOPT_TIMEOUT;
             if (strEQ(name, "TIMEOUT_MS")) return CURLOPT_TIMEOUT_MS;
@@ -964,6 +1025,8 @@ constant(const char *name)
         case 'Q':
         case 'R':
         case 'S':
+            if (strEQ(name, "STRINGPOINT")) return CURLOPTTYPE_STRINGPOINT;
+            break;
         case 'T':
         case 'U':
         case 'V':
@@ -1090,6 +1153,8 @@ constant(const char *name)
             if (strEQ(name, "PIPELINING")) return CURLMOPT_PIPELINING;
             if (strEQ(name, "PIPELINING_SERVER_BL")) return CURLMOPT_PIPELINING_SERVER_BL;
             if (strEQ(name, "PIPELINING_SITE_BL")) return CURLMOPT_PIPELINING_SITE_BL;
+            if (strEQ(name, "PUSHDATA")) return CURLMOPT_PUSHDATA;
+            if (strEQ(name, "PUSHFUNCTION")) return CURLMOPT_PUSHFUNCTION;
             break;
         case 'Q':
         case 'R':
@@ -1309,6 +1374,7 @@ constant(const char *name)
         name += 9;
         switch (*name) {
         case 'A':
+            if (strEQ(name, "ACTIVESOCKET")) return CURLINFO_ACTIVESOCKET;
             if (strEQ(name, "APPCONNECT_TIME")) return CURLINFO_APPCONNECT_TIME;
             break;
         case 'B':
@@ -1317,7 +1383,9 @@ constant(const char *name)
             if (strEQ(name, "CONDITION_UNMET")) return CURLINFO_CONDITION_UNMET;
             if (strEQ(name, "CONNECT_TIME")) return CURLINFO_CONNECT_TIME;
             if (strEQ(name, "CONTENT_LENGTH_DOWNLOAD")) return CURLINFO_CONTENT_LENGTH_DOWNLOAD;
+            if (strEQ(name, "CONTENT_LENGTH_DOWNLOAD_T")) return CURLINFO_CONTENT_LENGTH_DOWNLOAD_T;
             if (strEQ(name, "CONTENT_LENGTH_UPLOAD")) return CURLINFO_CONTENT_LENGTH_UPLOAD;
+            if (strEQ(name, "CONTENT_LENGTH_UPLOAD_T")) return CURLINFO_CONTENT_LENGTH_UPLOAD_T;
             if (strEQ(name, "CONTENT_TYPE")) return CURLINFO_CONTENT_TYPE;
             if (strEQ(name, "COOKIELIST")) return CURLINFO_COOKIELIST;
             break;
@@ -1342,6 +1410,7 @@ constant(const char *name)
             if (strEQ(name, "HTTPAUTH_AVAIL")) return CURLINFO_HTTPAUTH_AVAIL;
             if (strEQ(name, "HTTP_CODE")) return CURLINFO_HTTP_CODE;
             if (strEQ(name, "HTTP_CONNECTCODE")) return CURLINFO_HTTP_CONNECTCODE;
+            if (strEQ(name, "HTTP_VERSION")) return CURLINFO_HTTP_VERSION;
             break;
         case 'I':
         case 'J':
@@ -1362,6 +1431,7 @@ constant(const char *name)
             if (strEQ(name, "NUM_CONNECTS")) return CURLINFO_NUM_CONNECTS;
             break;
         case 'O':
+            if (strEQ(name, "OFF_T")) return CURLINFO_OFF_T;
             if (strEQ(name, "OS_ERRNO")) return CURLINFO_OS_ERRNO;
             break;
         case 'P':
@@ -1369,7 +1439,10 @@ constant(const char *name)
             if (strEQ(name, "PRIMARY_IP")) return CURLINFO_PRIMARY_IP;
             if (strEQ(name, "PRIMARY_PORT")) return CURLINFO_PRIMARY_PORT;
             if (strEQ(name, "PRIVATE")) return CURLINFO_PRIVATE;
+            if (strEQ(name, "PROTOCOL")) return CURLINFO_PROTOCOL;
             if (strEQ(name, "PROXYAUTH_AVAIL")) return CURLINFO_PROXYAUTH_AVAIL;
+            if (strEQ(name, "PROXY_SSL_VERIFYRESULT")) return CURLINFO_PROXY_SSL_VERIFYRESULT;
+            if (strEQ(name, "PTR")) return CURLINFO_PTR;
             break;
         case 'Q':
         case 'R':
@@ -1384,11 +1457,17 @@ constant(const char *name)
             if (strEQ(name, "RTSP_SESSION_ID")) return CURLINFO_RTSP_SESSION_ID;
             break;
         case 'S':
+            if (strEQ(name, "SCHEME")) return CURLINFO_SCHEME;
             if (strEQ(name, "SIZE_DOWNLOAD")) return CURLINFO_SIZE_DOWNLOAD;
+            if (strEQ(name, "SIZE_DOWNLOAD_T")) return CURLINFO_SIZE_DOWNLOAD_T;
             if (strEQ(name, "SIZE_UPLOAD")) return CURLINFO_SIZE_UPLOAD;
+            if (strEQ(name, "SIZE_UPLOAD_T")) return CURLINFO_SIZE_UPLOAD_T;
             if (strEQ(name, "SLIST")) return CURLINFO_SLIST;
+            if (strEQ(name, "SOCKET")) return CURLINFO_SOCKET;
             if (strEQ(name, "SPEED_DOWNLOAD")) return CURLINFO_SPEED_DOWNLOAD;
+            if (strEQ(name, "SPEED_DOWNLOAD_T")) return CURLINFO_SPEED_DOWNLOAD_T;
             if (strEQ(name, "SPEED_UPLOAD")) return CURLINFO_SPEED_UPLOAD;
+            if (strEQ(name, "SPEED_UPLOAD_T")) return CURLINFO_SPEED_UPLOAD_T;
             if (strEQ(name, "SSL_DATA_IN")) return CURLINFO_SSL_DATA_IN;
             if (strEQ(name, "SSL_DATA_OUT")) return CURLINFO_SSL_DATA_OUT;
             if (strEQ(name, "SSL_ENGINES")) return CURLINFO_SSL_ENGINES;
@@ -1399,6 +1478,7 @@ constant(const char *name)
         case 'T':
             if (strEQ(name, "TEXT")) return CURLINFO_TEXT;
             if (strEQ(name, "TLS_SESSION")) return CURLINFO_TLS_SESSION;
+            if (strEQ(name, "TLS_SSL_PTR")) return CURLINFO_TLS_SSL_PTR;
             if (strEQ(name, "TOTAL_TIME")) return CURLINFO_TOTAL_TIME;
             if (strEQ(name, "TYPEMASK")) return CURLINFO_TYPEMASK;
             break;
@@ -1660,6 +1740,7 @@ constant(const char *name)
             break;
         case 'C':
             if (strEQ(name, "CONTENTHEADER")) return CURLFORM_CONTENTHEADER;
+            if (strEQ(name, "CONTENTLEN")) return CURLFORM_CONTENTLEN;
             if (strEQ(name, "CONTENTSLENGTH")) return CURLFORM_CONTENTSLENGTH;
             if (strEQ(name, "CONTENTTYPE")) return CURLFORM_CONTENTTYPE;
             if (strEQ(name, "COPYCONTENTS")) return CURLFORM_COPYCONTENTS;
@@ -1857,6 +1938,7 @@ constant(const char *name)
             break;
         case 'H':
             if (strEQ(name, "HTTP2")) return CURLE_HTTP2;
+            if (strEQ(name, "HTTP2_STREAM")) return CURLE_HTTP2_STREAM;
             if (strEQ(name, "HTTP_NOT_FOUND")) return CURLE_HTTP_NOT_FOUND;
             if (strEQ(name, "HTTP_PORT_FAILED")) return CURLE_HTTP_PORT_FAILED;
             if (strEQ(name, "HTTP_POST_ERROR")) return CURLE_HTTP_POST_ERROR;
@@ -1948,6 +2030,7 @@ constant(const char *name)
             break;
         case 'V':
         case 'W':
+            if (strEQ(name, "WEIRD_SERVER_REPLY")) return CURLE_WEIRD_SERVER_REPLY;
             if (strEQ(name, "WRITE_ERROR")) return CURLE_WRITE_ERROR;
             break;
         case 'X':
@@ -2019,6 +2102,7 @@ constant(const char *name)
         case 'E':
         case 'F':
         case 'G':
+            if (strEQ(name, "GSSAPI")) return CURLAUTH_GSSAPI;
             if (strEQ(name, "GSSNEGOTIATE")) return CURLAUTH_GSSNEGOTIATE;
             break;
         case 'H':
